@@ -17,7 +17,7 @@ from tableau_api_lib.exceptions import InvalidParameterException
 
 def get_schedule_details(conn, schedule_names=None):
     schedules_df = get_schedules_dataframe(conn)
-    if any(schedule_names):
+    if schedule_names:
         schedules_df = schedules_df.loc[schedules_df['name'].isin(schedule_names)]
     schedule_ids = list(schedules_df['id'])
     schedule_details = [conn.update_schedule(schedule_id).json()['schedule'] for schedule_id in schedule_ids]
@@ -39,7 +39,8 @@ def create_base_schedules(conn,
                                         schedule_frequency=schedule['frequency'],
                                         start_time=schedule['frequencyDetails']['start'],
                                         end_time=schedule['frequencyDetails'].get('end', None),
-                                        interval_expression_list=schedule['frequencyDetails']['intervals']['interval'])
+                                        interval_expression_list=schedule['frequencyDetails']['intervals']['interval']
+                                        if schedule['frequencyDetails'].get('intervals') else None)
         try:
             responses.append(response.json()['schedule'])
         except KeyError:
